import pathlib


METADATA_SCHEMA = sorted(["Path", "From", "Date"])


def make_email_metadata(email_path: str) -> dict[str, str]:
    """Make an email metadata object by parsing the email contents

    Args:
        email_path:
        email_contents: Contents of an email file (from f.readlines())

    Returns: Dict containing the required metadata
    """
    key_is_set = {key: False for key in METADATA_SCHEMA}
    metadata = {"Path": email_path}
    key_is_set["Path"] = True

    with open(email_path, "r") as f:
        for line in f:
            try:
                k, v = [val.strip() for val in line.split(":", maxsplit=1)]
                if k in METADATA_SCHEMA:
                    metadata[k] = v
                    key_is_set[k] = True
                    if all([v for _, v in key_is_set.items()]):
                        break
            # If it's not a metadata line just pass
            except ValueError:
                pass

    # Validate that all keys have been found
    assert sorted(list(metadata.keys())) == METADATA_SCHEMA
    return metadata


def parse_maildir(path_to_dir: str | pathlib.Path):
    """Parse all of the emails within the specified maildir box (not recursively)

    Args:
        path_to_dir: Path to maildir

    Returns: MailDir object initialized with email information

    """
    return MailDir(_)


class MailDir:
    """Representation of the local maildir repository.
    Stores the metadata associated with all local emails.
    """

    def __init__(self, email_metadata: list[dict[str, str]]):
        pass
